ALTER TABLE noeuds RENAME TO old_noeuds;;
ALTER TABLE noeuds_second_milieu RENAME TO old_noeuds_second_milieu;;
CREATE TABLE noeuds (
    OGC_FID INTEGER PRIMARY KEY,
    surface REAL,
    infiltration REAL,
    altitude REAL,
    altitude_mur REAL,
    epaisseur_aquifere REAL,
    potentiel_reference REAL,
    potentiel REAL,
    debit_massique_eau REAL,
    epaisseur_zs REAL,
    epaisseur_zns REAL,
    permeabilite_zns REAL, -- used for permnoeuds.insat
    permeabilite_x REAL,
    permeabilite_y REAL,
    v_x REAL,
    v_y REAL,
    v_norme REAL,
    groupe INTEGER);;
DELETE FROM geometry_columns WHERE f_table_name='noeuds';;
DROP TABLE idx_noeuds_GEOMETRY;;
SELECT AddGeometryColumn('noeuds', 'GEOMETRY', SRID, 'POINT', 'XY');;
SELECT CreateSpatialIndex('noeuds', 'GEOMETRY');;

CREATE TABLE noeuds_second_milieu(
    OGC_FID INTEGER PRIMARY KEY REFERENCES noeuds(OGC_FID) ON UPDATE CASCADE ON DELETE CASCADE,
    infiltration REAL,
    epaisseur_aquifere REAL,
    potentiel_reference REAL,
    potentiel REAL,
    debit_massique_eau REAL,
    epaisseur_zs REAL,
    epaisseur_zns REAL,
    permeabilite_zns REAL,
    permeabilite_x REAL,
    permeabilite_y REAL,
    transmissivite_x REAL,
    transmissivite_y REAL,
    v_x REAL,
    v_y REAL,
    v_norme REAL);;

INSERT INTO noeuds(
    OGC_FID,
    surface,
    infiltration,
    altitude,
    altitude_mur,
    epaisseur_aquifere,
    potentiel_reference,
    potentiel,
    debit_massique_eau,
    epaisseur_zs,
    epaisseur_zns,
    permeabilite_zns,
    permeabilite_x,
    permeabilite_y,
    groupe,
    GEOMETRY) SELECT
    OGC_FID,
    surface,
    infiltration,
    altitude,
    altitude_mur,
    epaisseur_aquifere,
    potentiel_reference,
    potentiel,
    pot_gradient_x,
    epaisseur_zs,
    epaisseur_zns,
    permeabilite_zns,
    permeabilite_x,
    permeabilite_y,
    groupe,
    GEOMETRY FROM old_noeuds;;

INSERT INTO noeuds_second_milieu(
    OGC_FID,
    infiltration,
    epaisseur_aquifere,
    potentiel_reference,
    potentiel,
    debit_massique_eau,
    epaisseur_zs,
    epaisseur_zns,
    permeabilite_zns,
    permeabilite_x,
    permeabilite_y) SELECT
    OGC_FID,
    infiltration,
    epaisseur_aquifere,
    potentiel_reference,
    potentiel,
    pot_gradient_x,
    epaisseur_zs,
    epaisseur_zns,
    permeabilite_zns,
    permeabilite_x,
    permeabilite_y FROM old_noeuds_second_milieu;;


DROP TABLE old_noeuds;;
DROP TABLE old_noeuds_second_milieu;;


ALTER TABLE mailles RENAME TO old_mailles;;
ALTER TABLE mailles_second_milieu RENAME TO old_mailles_second_milieu;;

CREATE TABLE mailles (
    OGC_FID INTEGER PRIMARY KEY,
    a INTEGER REFERENCES noeuds(OGC_FID)
        ON UPDATE CASCADE ON DELETE CASCADE,
    b INTEGER REFERENCES noeuds(OGC_FID)
        ON UPDATE CASCADE ON DELETE CASCADE,
    c INTEGER REFERENCES noeuds(OGC_FID)
        ON UPDATE CASCADE ON DELETE CASCADE,
    d INTEGER REFERENCES noeuds(OGC_FID)
        ON UPDATE CASCADE ON DELETE CASCADE,
    surface REAL,
    infiltration REAL,
    altitude REAL,
    altitude_mur REAL,
    epaisseur_aquifere REAL,
    potentiel_reference REAL,
    potentiel REAL,
    suintement REAL,
    epaisseur_zs REAL,
    epaisseur_zns REAL,
    permeabilite_zns REAL, -- used for permnoeuds.insat
    permeabilite_x REAL,
    permeabilite_y REAL,
    transmissivite_x REAL,
    transmissivite_y REAL,
    v_x REAL,
    v_y REAL,
    v_norme REAL);;

DELETE FROM geometry_columns WHERE f_table_name='mailles';;
DROP TABLE idx_mailles_GEOMETRY;;
SELECT AddGeometryColumn('mailles', 'GEOMETRY', SRID, 'POLYGON', 'XY');;
SELECT CreateSpatialIndex('mailles', 'GEOMETRY');;

INSERT INTO mailles(OGC_FID, a, b, c, d, permeabilite_x, permeabilite_y, v_x, v_y, v_norme, GEOMETRY) SELECT OGC_FID, a, b, c, d, permeabilite_x, permeabilite_y, v_x, v_y, v_norme, GEOMETRY FROM old_mailles;;
DROP TABLE old_mailles;;


CREATE TABLE mailles_second_milieu(
    OGC_FID INTEGER PRIMARY KEY REFERENCES mailles(OGC_FID) ON UPDATE CASCADE ON DELETE CASCADE,
    surface REAL,
    infiltration REAL,
    epaisseur_aquifere REAL,
    potentiel_reference REAL,
    potentiel REAL,
    suintement REAL,
    epaisseur_zs REAL,
    epaisseur_zns REAL,
    permeabilite_zns REAL, -- used for permnoeuds.insat
    permeabilite_x REAL,
    permeabilite_y REAL,
    transmissivite_x REAL,
    transmissivite_y REAL,
    v_x REAL,
    v_y REAL,
    v_norme REAL);;

INSERT INTO mailles_second_milieu(OGC_FID, permeabilite_x, permeabilite_y, v_x, v_y, v_norme) SELECT OGC_FID, permeabilite_x, permeabilite_y, v_x, v_y, v_norme FROM old_mailles_second_milieu;;
DROP TABLE old_mailles_second_milieu;;

